summaryrefslogtreecommitdiff
path: root/modules/mappers/mod_so.c
diff options
context:
space:
mode:
authorRyan Bloom <rbb@apache.org>1999-08-31 05:35:52 +0000
committerRyan Bloom <rbb@apache.org>1999-08-31 05:35:52 +0000
commitc37f14ddf32319a7d84a9b573a54ccde8f37c5ff (patch)
tree1f1dd08b2e53226b3b3363beee02eeb57a8061ca /modules/mappers/mod_so.c
parente6991d4075b55b175a6fb0cfe849566f863f27ac (diff)
downloadhttpd-c37f14ddf32319a7d84a9b573a54ccde8f37c5ff.tar.gz
Changed pools to contexts. Tested with prefork and pthread mpm's. I'll
check this out tomorrow and make sure everything was checked in correctly. git-svn-id: https://svn.apache.org/repos/asf/httpd/httpd/trunk@83852 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'modules/mappers/mod_so.c')
-rw-r--r--modules/mappers/mod_so.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/modules/mappers/mod_so.c b/modules/mappers/mod_so.c
index f0c2a7b7db..1c8cbff455 100644
--- a/modules/mappers/mod_so.c
+++ b/modules/mappers/mod_so.c
@@ -101,7 +101,7 @@
* You can use this to dynamically change the capability of your server
* without bringing it down.
*
* Because currently there is only limited built-in support in the Configure
* script for creating the shared library files (`.so'), please consult your
* vendors cc(1), ld(1) and dlopen(3) manpages to find out the appropriate
* compiler and linker flags and insert them manually into the Configuration
@@ -144,10 +144,10 @@ typedef struct moduleinfo {
} moduleinfo;
typedef struct so_server_conf {
- array_header *loaded_modules;
+ ap_array_header_t *loaded_modules;
} so_server_conf;
-static void *so_sconf_create(pool *p, server_rec *s)
+static void *so_sconf_create(ap_context_t *p, server_rec *s)
{
so_server_conf *soc;
@@ -269,7 +269,7 @@ static const char *load_module(cmd_parms *cmd, void *dummy,
ap_add_loaded_module(modp);
/*
* Register a cleanup in the config pool (normally pconf). When
* we do a restart (or shutdown) this cleanup will cause the
* shared object to be unloaded.
*/
@@ -344,7 +344,7 @@ module MODULE_VAR_EXPORT so_module = {
NULL, /* merge per-dir config */
so_sconf_create, /* server config */
NULL, /* merge server config */
- so_cmds, /* command table */
+ so_cmds, /* command ap_table_t */
NULL, /* handlers */
NULL, /* filename translation */
NULL, /* check_user_id */
@@ -101,7 +101,7 @@
* without bringing it down.
*
- * Because currently there is only limited built-in support in the Configure
+ * Because currently there is only limited built ap_context_t n support in the Configure
* script for creating the shared library files (`.so'), please consult your
* vendors cc(1), ld(1) and dlopen(3) manpages to find out the appropriate
@@ -269,7 +269,7 @@ static const char *load_module(cmd_parms *cmd, void *dummy,
ap_add_loaded_module(modp);
/*
- * Register a cleanup in the config pool (normally pconf). When
+ * Register a cleanup in the config ap_context_t (normally pconf). When
* we do a restart (or shutdown) this cleanup will cause the
* shared object to be unloaded.